==> test-engine-5.1.9-sources.jar: com/xebialabs/deployit/itest/cloudhost/WaitForOpenPortTransformer.java <==
package com.xebialabs.deployit.itest.cloudhost;

import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.base.Function;
import com.google.common.util.concurrent.ListenableFuture;

import com.xebialabs.deployit.booter.local.utils.Closeables;
import com.xebialabs.overcast.host.CloudHost;

public class WaitForOpenPortTransformer implements CloudHostFutureTransformer {
    private static final Logger logger = LoggerFactory.getLogger(WaitForOpenPortTransformer.class);
    private final int port;
    private final int timeoutSeconds;

    public WaitForOpenPortTransformer(int port, int timeoutSeconds) {
        this.port = port;
        this.timeoutSeconds = timeoutSeconds;
    }

    @Override
    public Function<CloudHost, CloudHost> transform(ListenableFuture<CloudHost> host) {
        return new Function<CloudHost, CloudHost>() {
            @Override
            public CloudHost apply(CloudHost host) {
                logger.info("Waiting for port {}:{}", host.getHostName(), port);
                waitForPort(host.getHostName(), port, timeoutSeconds);
                return host;
            }
        };
    }

    public static void waitForPort(String hostOrIp, int port, int timeoutSeconds) {
        int i = 0;
        while (i < timeoutSeconds) {
            if (isPortOpen(hostOrIp, port)) {
                logger.info("Port {}:{} is open.", hostOrIp, port);
                return;
            }
            try {
                Thread.sleep(1000);
            } catch (InterruptedException e) {
                logger.debug("Interrupted stopping waitForPort {}:{}", hostOrIp, port);
                break;
            }
            i++;
        }
        throw new RuntimeException(String.format("Timeout expired waiting for port %s:%d", hostOrIp, port));
    }

    public static boolean isPortOpen(String hostOrIp, int port) {
        final int timeout = 5000;
        Socket socket = new Socket();
        InetSocketAddress endPoint;
        try {
            endPoint = new InetSocketAddress(InetAddress.getByName(hostOrIp), port);
            if (endPoint.isUnresolved()) {
                return false;
            }
            socket.connect(endPoint, timeout);
            return true;
        } catch (IOException e) {
            logger.debug("Exception testing connection to {}:{}: {}", hostOrIp, port, e.getMessage());
        } finally {
            Closeables.closeQuietly(socket);
        }
        return false;
    }
}

==> test-engine-25.1.4-720.1713-sources.jar: com/xebialabs/deployit/itest/cloudhost/WaitForOpenPortTransformer.java <==
package com.xebialabs.deployit.itest.cloudhost;

import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.google.common.base.Function;
import com.google.common.util.concurrent.ListenableFuture;

import com.xebialabs.deployit.booter.local.utils.Closeables;
import com.xebialabs.overcast.host.CloudHost;

public class WaitForOpenPortTransformer implements CloudHostFutureTransformer {
    private static final Logger logger = LoggerFactory.getLogger(WaitForOpenPortTransformer.class);
    private final int port;
    private final int timeoutSeconds;

    public WaitForOpenPortTransformer(int port, int timeoutSeconds) {
        this.port = port;
        this.timeoutSeconds = timeoutSeconds;
    }

    @Override
    public Function<CloudHost, CloudHost> transform(ListenableFuture<CloudHost> host) {
        return (CloudHost ch) -> {
            logger.info("Waiting for port {}:{}", ch.getHostName(), port);
            waitForPort(ch.getHostName(), port, timeoutSeconds);
            return ch;
        };
    }

    public static void waitForPort(String hostOrIp, int port, int timeoutSeconds) {
        int i = 0;
        while (i < timeoutSeconds) {
            if (isPortOpen(hostOrIp, port)) {
                logger.info("Port {}:{} is open.", hostOrIp, port);
                return;
            }
            try {
                Thread.sleep(1000);
            } catch (InterruptedException e) {
                logger.debug("Interrupted stopping waitForPort {}:{}", hostOrIp, port);
                break;
            }
            i++;
        }
        throw new RuntimeException(String.format("Timeout expired waiting for port %s:%d", hostOrIp, port));
    }

    public static boolean isPortOpen(String hostOrIp, int port) {
        final int timeout = 5000;
        Socket socket = new Socket();
        InetSocketAddress endPoint;
        try {
            endPoint = new InetSocketAddress(InetAddress.getByName(hostOrIp), port);
            if (endPoint.isUnresolved()) {
                return false;
            }
            socket.connect(endPoint, timeout);
            return true;
        } catch (IOException e) {
            logger.debug("Exception testing connection to {}:{}: {}", hostOrIp, port, e.getMessage());
        } finally {
            Closeables.closeQuietly(socket);
        }
        return false;
    }
}
